# Installation

## Stable release

To install geoai, run this command in your terminal:

```bash
pip install geoai-py
```

This is the preferred method to install geoai, as it will always install the most recent stable release.

If you don't have [pip](https://pip.pypa.io) installed, this [Python installation guide](http://docs.python-guide.org/en/latest/starting/installation/) can guide you through the process.

## From sources

To install geoai from sources, run this command in your terminal:

```bash
pip install git+https://github.com/opengeos/geoai
```
